==> sfc_models-0.3.0-py2.py3-none-any.whl: sfc_models/examples/scripts/SIM_Model_With_Capitalists.py <==
"""
SIM_Model_With_Capitalists.py

Extend the SIM model (Godley and Lavoie, Chapter 3) with a capitalist sub-sector.

Copyright 2016 Brian Romanchuk

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""


from sfc_models.examples.Quick2DPlot import Quick2DPlot
from sfc_models.models import *
from sfc_models.sectors import Household, DoNothingGovernment, TaxFlow, FixedMarginBusiness, Capitalists


def CreateCountry(mod, name, code):
    # Create the country.
    cntry = Country(mod, name, code)
    # Create sectors
    DoNothingGovernment(cntry, 'Government', 'GOV')
    Household(cntry, 'Household', 'HH', alpha_income=.75, alpha_fin=.5)
    Capitalists(cntry, 'Capitalists', 'CAP', alpha_income=.2, alpha_fin=.3)
    # A literally non-profit business sector
    FixedMarginBusiness(cntry, 'Business Sector', 'BUS', profit_margin=0.2)
    # Create the linkages between sectors - tax flow, markets - labour ('LAB'), goods ('GOOD')
    TaxFlow(cntry, 'TaxFlow', 'TF', .2)
    Market(cntry, 'Labour market', 'LAB')
    Market(cntry, 'Goods market', 'GOOD')
    return cntry

def main():
    # Create model, which holds all entities
    mod = Model()
    can = CreateCountry(mod, 'Canada', 'CA')
    us = CreateCountry(mod, 'United states', 'US')
    # Need to set the exogenous variable - Government demand for Goods ("G" in economist symbology)
    mod.AddExogenous('CA_GOV', 'DEM_GOOD', '[20.,] * 105')
    mod.AddExogenous('US_GOV', 'DEM_GOOD', '[20.,] * 105')
    # Build the model
    # Output is put into two files, based on the file name passed into main() ['ex20161128_tax_cut_comparison']
    # (1) [...]_log.txt:  Log file
    # (2) [...].py:  File that solves the system of equations
    eqns = mod.main_deprecated('ex20161128_tax_cut_comparison')
    import ex20161128_tax_cut_comparison
    obj = SIM_Capitalist.SFCModel()
    obj.MaxTime = 20
    obj.PrintIterations = True
    obj.main()
    obj.WriteCSV('ex20161128_tax_cut_comparison.csv')

    p = Quick2DPlot([obj.t, obj.t], [obj.CA_GOOD_SUP_GOOD, obj.US_GOOD_SUP_GOOD], 'Output - Y', run_now=False)
    p.Legend = ['Scenario #1', 'Scenario #2']
    p.DoPlot()
    # p = Quick2DPlot([obj.t, obj.t], [obj.BUS_F, obj2.BUS_F], 'Business Sector Financial Assets (F)', run_now=False)
    # p.Legend = ['Canada (0% profit)', 'U.S. (10% Profit)']
    # p.DoPlot()
    # p = Quick2DPlot([obj.t, obj.t], [obj.GOV_FISC_BAL, obj2.GOV_FISC_BAL], 'Government Financial Balance',
    #                 run_now=False)
    # p.Legend = ['Canada (0% profit)', 'U.S. (10% Profit)']
    # p.DoPlot()

if __name__ == '__main__':
    main()

==> sfc_models-0.4.0-py2.py3-none-any.whl: sfc_models/examples/scripts/SIM_Model_With_Capitalists.py <==
"""
SIM_Model_With_Capitalists.py

Extend the SIM model (Godley and Lavoie, Chapter 3) with a capitalist sub-sector.

Copyright 2016 Brian Romanchuk

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""


from sfc_models.examples.Quick2DPlot import Quick2DPlot
from sfc_models.utils import register_standard_logs
from sfc_models.models import Model, Country
from sfc_models.sector import Market
from sfc_models.utils import Logger, get_file_base
from sfc_models.sector_definitions import Household, DoNothingGovernment, TaxFlow, FixedMarginBusiness, Capitalists


def CreateCountry(mod, name, code):
    # Create the country.
    cntry = Country(mod, name, code)
    # Create sectors
    DoNothingGovernment(cntry, 'Government', 'GOV')
    Household(cntry, 'Household', 'HH', alpha_income=.75, alpha_fin=.5)
    Capitalists(cntry, 'Capitalists', 'CAP', alpha_income=.2, alpha_fin=.3)
    # A literally non-profit business sector
    FixedMarginBusiness(cntry, 'Business Sector', 'BUS', profit_margin=0.2)
    # Create the linkages between sectors - tax flow, markets - labour ('LAB'), goods ('GOOD')
    TaxFlow(cntry, 'TaxFlow', 'TF', .2)
    Market(cntry, 'Labour market', 'LAB')
    Market(cntry, 'Goods market', 'GOOD')
    return cntry


def main():
    # The next line of code sets the name of the output files based on the code file's name.
    # This means that if you paste this code into a new file, get a new log name.
    register_standard_logs('output', __file__)
    # Create model, which holds all entities
    mod = Model()
    can = CreateCountry(mod, 'Canada', 'CA')
    us = CreateCountry(mod, 'United states', 'US')
    # Need to set the exogenous variable - Government demand for Goods ("G" in economist symbology)
    mod.AddExogenous('CA_GOV', 'DEM_GOOD', '[20.,] * 105')
    mod.AddExogenous('US_GOV', 'DEM_GOOD', '[20.,] * 105')
    mod.main()


if __name__ == '__main__':
    main()
